@@ -40,4 +40,11 @@ class Renderer:
         :param init_pos:
         :param end_pos:
         :return:
+        """
+
+    def get_pos(self, entity):
+        """
+        Get the position of the entity in the World
+        :param entity:
+        :return: the position in Vec3 format
         """
\ No newline at end of file
